# Aquativo - Copyright (C) 2004 Pat Thoyts <patthoyts@users.sourceforge.net>
#
# Import the Aquativo Gtk theme (C) Andrew Wyatt, FEWT Software
# Original: http://www.fewt.com
# Link: http://art.gnome.org/themes/gtk2/432.php
#
# You will need to fetch the theme package and extract it under the 
# demos/themes directory and maybe modify the demos/themes/pkgIndex.tcl
# file.
#
# $Id: Aquativo.tcl,v 1.10 2004/02/04 00:56:35 jenglish Exp $

package require tile::pixmap
package require Img

namespace eval Tile {
    namespace eval Aquativo {
        variable version 0.0.1
    }
}

namespace eval Tile::Aquativo {

style createtheme Aquativo -parent alt -settings {

    # ---------------------------------------------------------------------
    # Layouts
    # ---------------------------------------------------------------------

    style definelayout TButton {
        Button.background
	Button.padding -children {
	    Button.highlight -expand true -children {
		Button.compound
	    }
        }
    }

    # ---------------------------------------------------------------------
    # Troughs
    # ---------------------------------------------------------------------

    style createelement trough pixmap -images {
        {}                  ::Tile::Aquativo::_i_horizontal_trough
    } -border 3 -tiling tile -background opaque
    style createelement Vertical.Scrollbar.trough pixmap -images {
        {}                  ::Tile::Aquativo::_i_vertical_trough
    } -border 2 -tiling tile -background opaque
    style createelement Vertical.Scale.trough pixmap -images {
        {}                  ::Tile::Aquativo::_i_vertical_trough
    } -border 2 -tiling tile -background opaque
    style createelement Vertical.Progress.trough pixmap -images {
        {}                  ::Tile::Aquativo::_i_vertical_trough
    } -border 2 -tiling tile -background opaque


    # ---------------------------------------------------------------------
    # Buttons, Checkbuttons and Radiobuttons
    # ---------------------------------------------------------------------

    style createelement Button.background pixmap -images {
        {pressed !disabled} ::Tile::Aquativo::_i_button_normal_in
        {active !disabled}  ::Tile::Aquativo::_i_button_prelight_out
        disabled            ::Tile::Aquativo::_i_button_insensitive_out
        {}                  ::Tile::Aquativo::_i_button_normal_out
    } -border 10 -tiling tile -background opaque

    style createelement Checkbutton.indicator pixmap -images {
        {selected !disabled}  ::Tile::Aquativo::_i_check_in
        {}                    ::Tile::Aquativo::_i_check_out
    } -border 2 -tiling fixed

    style createelement Radiobutton.indicator pixmap -images {
        {selected !disabled}  ::Tile::Aquativo::_i_option_in
        {}                    ::Tile::Aquativo::_i_option_out
    } -border 2 -tiling fixed

    # ---------------------------------------------------------------------
    # Scrollbar
    # ---------------------------------------------------------------------

    style createelement Horizontal.Scrollbar.thumb pixmap -images {
        {active !disabled}  ::Tile::Aquativo::_i_scrollbar_prelight_horizontal
        {}                  ::Tile::Aquativo::_i_scrollbar_horizontal
    } -border 3 -tiling tile -minsize {8 0}

    style createelement Vertical.Scrollbar.thumb pixmap -images {
        {active !disabled}  ::Tile::Aquativo::_i_scrollbar_prelight_vertical
        {}                  ::Tile::Aquativo::_i_scrollbar_vertical
    } -border 3 -tiling tile -minsize {0 8}

    # ---------------------------------------------------------------------
    # Scale
    # ---------------------------------------------------------------------

    style createelement Horizontal.Scale.slider pixmap -images {
        {active !disabled}  ::Tile::Aquativo::_i_scrollbar_prelight_horizontal
        {}                  ::Tile::Aquativo::_i_scrollbar_horizontal
    } -border 3 -tiling tile -minsize {30 0}

    style createelement Vertical.Scale.slider pixmap -images {
        {active !disabled}  ::Tile::Aquativo::_i_scrollbar_prelight_vertical
        {}                  ::Tile::Aquativo::_i_scrollbar_vertical
    } -border 3 -tiling tile -minsize {0 30}

    # ---------------------------------------------------------------------
    # Progress
    # ---------------------------------------------------------------------

    # should use ::Tile::Aquativo::_i_progressbar but this is too big.
    style createelement bar pixmap -images {
        {} ::Tile::Aquativo::_i_scrollbar_prelight_horizontal
    } -border 3 -tiling tile
    style createelement Vertical.Progress.bar pixmap -images {
        {} ::Tile::Aquativo::_i_scrollbar_prelight_vertical
    } -border 3 -tiling tile

    # ---------------------------------------------------------------------
    # Arrows
    # ---------------------------------------------------------------------

    style createelement uparrow pixmap -images {
        {pressed !disabled} ::Tile::Aquativo::_i_arrow_up_clicked
        disabled            ::Tile::Aquativo::_i_arrow_up_insensitive
        {}                  ::Tile::Aquativo::_i_arrow_up_normal
    } -tiling fixed
        
    style createelement downarrow pixmap -images {
        {pressed !disabled} ::Tile::Aquativo::_i_arrow_down_clicked
        disabled            ::Tile::Aquativo::_i_arrow_down_insensitive
        {}                  ::Tile::Aquativo::_i_arrow_down_normal
    } -tiling fixed

    style createelement leftarrow pixmap -images {
        {pressed !disabled} ::Tile::Aquativo::_i_arrow_left_clicked
        disabled            ::Tile::Aquativo::_i_arrow_left_insensitive
        {}                  ::Tile::Aquativo::_i_arrow_left_normal
    } -tiling fixed

    style createelement rightarrow pixmap -images {
        {pressed !disabled} ::Tile::Aquativo::_i_arrow_right_clicked
        disabled            ::Tile::Aquativo::_i_arrow_right_insensitive
        {}                  ::Tile::Aquativo::_i_arrow_right_normal
    } -tiling fixed

    # ---------------------------------------------------------------------
    # Notebook parts
    # ---------------------------------------------------------------------
    
    style createelement tab pixmap -images {
        {selected !disabled} ::Tile::Aquativo::_i_notebook_bottom
        {}                   ::Tile::Aquativo::_i_notebook_active_bottom
    } -tiling fixed

    # ---------------------------------------------------------------------
    # Frames parts
    # ---------------------------------------------------------------------

    # This make it REALLY SLOW
    #style createelement Frame.background pixmap -images {
    #    {}                   ::Tile::Aquativo::_i_window_background
    #} -tiling tile
    #style createelement Labelframe.background pixmap -images {
    #    {}                   ::Tile::Aquativo::_i_window_background
    #} -tiling tile

    # ---------------------------------------------------------------------
    # Load images
    # ---------------------------------------------------------------------

    set imgdir [file join [file dirname [info script]] Aquativo-1.5 gtk-2.0]
    foreach file [glob -directory $imgdir *.png] {
        set img [file tail [file rootname $file]]
        image create photo [namespace current]::_i_$img -file $file
    }

    style default . -background #fafafa
    style default TButton -padding "3 3" -font ButtonFont -width -11
    style default TNotebookTab -padding "3m 1m" -font ButtonFont

} }

# -------------------------------------------------------------------------

package provide tile::theme::Aquativo $::Tile::Aquativo::version

# -------------------------------------------------------------------------
